@@ -36,7 +36,7 @@ use warnings;
  
 package Tiezi::Robot;
 
-our $VERSION=0.10;
+our $VERSION=0.11;
 
 use utf8;
 
@@ -91,69 +91,129 @@ sub set_packer {
 
 } ## end sub set_packer
 
+
 sub get_tiezi {
     my ( $self, $tz_url, $o ) = @_; 
     $o ||= {}; 
 
-    my $tz = $self->get_tiezi_ref($tz_url);
+
+    my $tz = $self->get_tiezi_ref($tz_url, $o);
     return unless ($tz and $tz->{topic} and $tz->{topic}{name} and $tz->{topic}{title});
     $tz->{topic}{url} = $tz_url;
-    
-    #选取指定楼层
-    if($o->{skip_floor}){
-        for my $f (@{$tz->{floors}}){
-            $f->{skip} = $o->{skip_floor}->($tz, $f);
-        }
-    }
+
+    check_skip_floor($_, $o, $tz) for @{$tz->{floors}};
 
     $self->{packer}->open_packer($tz);
 
     $self->{packer}->format_before_toc($tz);
-    unless($o->{skip_toc}){
-        $self->{packer}->format_toc($tz);
-    }
+
+    $self->{packer}->format_toc($tz) if($o->{with_toc});
+
     $self->{packer}->format_after_toc($tz);
 
     $self->{packer}->format_before_floor($tz);
+
     for my $i (0 .. $#{$tz->{floors}}){
         my $d = $tz->{floors}[$i];
         next unless ($d);
 
         $self->{packer}->format_floor( $d, $i+1 );
     } ## end for my $i ( 1 .. $tz...)
+
     $self->{packer}->format_after_floor($tz);
 
     $self->{packer}->close_packer();
 }
 
+sub check_skip_floor {
+    my ($d, $o, $tz) = @_;
+    return if(is_poster_floor($d, $o, $tz) and is_wordnum_overflow($d, $o));
+    $d->{skip} = 1;
+}
+
+sub is_wordnum_overflow {
+    my ( $floor, $o ) = @_;
+    return 1 unless($o->{min_word_num});
+    my $n = length( $floor->{content} );
+    return 1 if ( $n >= $o->{min_word_num} );
+    return;
+}
+
+sub is_poster_floor {
+    my ( $floor, $o, $r ) = @_;
+    return 1 unless($o->{only_poster});
+
+    return 1 if ( $floor->{name} eq $r->{topic}{name} );
+    return;
+}
+
+sub is_tiezi_overflow {
+    my ($f, $o) = @_;
+
+    return unless($o->{max_tiezi_num});
+
+    my $tiezi_num = scalar(@$f);
+    return if($tiezi_num < $o->{max_tiezi_num});
+
+    $#$f = $o->{max_tiezi_num} - 1;
+    return 1;
+}
+
+sub is_floor_overflow {
+    my ($f, $o) = @_;
+
+    return unless($o->{max_floor_num});
+
+    my $floor_num = scalar(@$f);
+    return if($floor_num < $o->{max_floor_num});
+
+    $#$f = $o->{max_floor_num} - 1;
+    return 1;
+}
+
+sub is_page_overflow {
+    my ($i, $o) = @_;
+    return unless($o->{max_page_num});
+    return if($i<$o->{max_page_num});
+    return 1;
+}
+
 sub get_tiezi_ref {
-    my ( $self, $url ) = @_;
+    my ( $self, $url, $o ) = @_;
+    $o ||= {};
     
-    my $html_ref = $self->{browser}->get_url_ref( $url );
+    my $html_ref = $self->{browser}->request_url( $url );
     return unless $html_ref;
     
     my %result;
     
     $result{topic} = $self->{parser}->parse_tiezi_topic($html_ref);
     $result{floors}          = $self->{parser}->parse_tiezi_floors($html_ref);
+    return \%result if(is_floor_overflow($result{floors}, $o));
+
     my $result_urls_ref = $self->{parser}->parse_tiezi_urls($html_ref);
     return \%result unless ( defined $result_urls_ref );
 
+    my $page_num = 2;
     for my $u (@$result_urls_ref) {
-        my $h = $self->{browser}->get_url_ref($u);
+
+        my $h = $self->{browser}->request_url($u);
         my $r = $self->{parser}->parse_tiezi_floors($h);
         push @{$result{floors}} , @$r;
+
+        return \%result if(is_floor_overflow($result{floors}, $o));
+        return \%result if(is_page_overflow($page_num, $o));
+
+        $page_num++; 
     }
     
-    $_->{title} ||= '' for(@{$result{floors}});
-
     return \%result;
 } ## end sub get_tiezi_ref
 
 sub get_board_ref {
-    my ( $self, $url , $return_sub ) = @_;
+    my ( $self, $url , $o ) = @_;
     
-    my $html_ref = $self->{browser}->get_url_ref( $url );
+    my $html_ref = $self->{browser}->request_url( $url );
     print "board : $url\n";
     return unless $html_ref;
     
@@ -163,51 +223,51 @@ sub get_board_ref {
 
     $result{subboards}          = $self->{parser}->parse_board_subboards($html_ref);
     $result{tiezis} = $self->{parser}->parse_board_tiezis($html_ref);
-    
-    $result{board_num} = 1;
-    $result{tiezi_num} = scalar(@{$result{tiezis}});
+    return \%result if(is_tiezi_overflow($result{tiezis}, $o));
     
     my $result_urls_ref = $self->{parser}->parse_board_urls($html_ref);
     return \%result unless ( defined $result_urls_ref );
 
+    my $page_num = 2;
     for my $u (@$result_urls_ref) {
         print "board : $u\n";
-        my $h = $self->{browser}->get_url_ref($u);
+        my $h = $self->{browser}->request_url($u);
         my $r = $self->{parser}->parse_board_tiezis($h);
         push @{$result{tiezis}} , @$r;
         
-        $result{board_num}++;
-        $result{tiezi_num} = scalar(@{$result{tiezis}});
-
-        return \%result if($return_sub and $return_sub->(\%result));
+        return \%result if(is_tiezi_overflow($result{tiezis}, $o));
+        return \%result if(is_page_overflow($page_num, $o));
+        $page_num++;
     }
     
     return \%result;
 } ## end sub get_board_ref
 
 sub get_query_ref {
-    my ( $self, $query, $return_sub) = @_;
+    my ( $self, $query, $o) = @_;
+    $o ||= {};
+
+    my ( $url, $post_vars ) = $self->{parser}->make_query_request( $query );
     
-    my ( $url, $post_vars ) = $self->{parser}->make_query_url( $query );
-    
-    my $html_ref = $self->{browser}->get_url_ref( $url, $post_vars );
+    my $html_ref = $self->{browser}->request_url( $url, $post_vars );
     return unless $html_ref;
 
     my %result;
     $result{tiezis}          = $self->{parser}->parse_query($html_ref);
+    return \%result if(is_tiezi_overflow($result{tiezis}, $o));
 
-    my $result_urls_ref = $self->{parser}->get_query_result_urls($html_ref);
+    my $result_urls_ref = $self->{parser}->parse_query_result_urls($html_ref);
     return \%result unless ( defined $result_urls_ref );
 
+    my $page_num = 2;
     for my $url (@$result_urls_ref) {
-        my $h = $self->{browser}->get_url_ref($url);
+        my $h = $self->{browser}->request_url($url);
         my $r = $self->{parser}->parse_query($h);
         push @{$result{tiezis}}, @$r;
         
-        $result{query_num}++;
-        $result{tiezi_num} = scalar(@{$result{tiezis}});
-
-        return \%result if($return_sub and $return_sub->(\%result));
+        return \%result if(is_tiezi_overflow($result{tiezis}, $o));
+        return \%result if(is_page_overflow($page_num, $o));
+        $page_num++;
     }
 
     return \%result;
